# Contribution Guidelines

Additional information is available at the following locations.

| Topic | Description | Location |
| --- | --- | --- |
| Code of Conduct | How we welcome others to this community. | [CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md) |
| Development Activities | How we create software in this community. | [DEVELOPMENT.md](DEVELOPMENT.md) |
| Security | How to report vulnerabilities in our software. | [SECURITY.md](SECURITY.md) |

# Bug Reports
If you experience a problem with our software, please visit [issues](https://github.com/gt-sse-center/iNatInqPerf/issues) and create a `Bug report`.

# Feature Requests
If you would like to suggest a new feature for our software, please visit [issues](https://github.com/gt-sse-center/iNatInqPerf/issues) and create a `Feature request`.

# Issue Labels
We use these labels to help us track and manage `Bug reports` and `Feature requests`.

| Label | Description |
| --- | --- |
| `bug` | Something isn't working. |
| `enhancement` | New feature or request. |
| `help wanted` | Extra attention is needed. |
| `good first issue` | Good for newcomers. |
| `documentation` | Improvements or additions to documentation. |
